@@ -1,15 +1,18 @@
  #Pearson or polychoric correlations with confidence intervals
 
  "cor.ci" <- 
-function(x, keys = NULL, n.iter = 100, p = 0.05, overlap=FALSE, poly = FALSE, method = "pearson",plot=TRUE,minlength=5,...) {
-corCi(x=x, keys = keys, n.iter = n.iter, p = p, overlap=overlap, poly = poly, method = method,plot=plot,minlength=minlength,...) }
+function(x, keys = NULL, n.iter = 100, p = 0.05, overlap=FALSE, poly = FALSE, method = "pearson",plot=TRUE,minlength=5,n=NULL,...) {
+corCi(x=x, keys = keys, n.iter = n.iter, p = p, overlap=overlap, poly = poly, method = method,plot=plot,minlength=minlength,n=n,...) }
 
  "corCi" <- 
-function(x, keys = NULL, n.iter = 100, p = 0.05, overlap=FALSE, poly = FALSE, method = "pearson",plot=TRUE,minlength=5,...) {
+function(x,keys = NULL, n.iter = 100, p = 0.05, overlap=FALSE, poly = FALSE, method = "pearson",plot=TRUE,minlength=5,n = NULL,...) {
 
  cl <- match.call()
  n.obs <- dim(x)[1]
  
+ if(!isCorrelation(x)) {#the normal case is to have data and find the correlations and then bootstrap them
+ #added the direct from correlation matrix option, August 17, 2019 since I was finding them for statsBy
+ 
  if(is.null(keys) && overlap) overlap <- FALSE  #can not correct for overlap with just items
 if(poly) {  #find polychoric or tetrachoric correlations if desired
   ncat <- 8
@@ -25,7 +28,7 @@ dvars <- subset(1:nvar,len==2)   #find the dichotomous variables
 pvars <- subset(1:nvar,((len > 2) & (len <= ncat)))  #find the polytomous variables
 cvars <- subset(1:nvar,(len > ncat))  #find the continuous variables (more than ncat levels)
 if(length(pvars)==ncol(x)) {tet <- polychoric(x)
-	    typ = "poly"} else {tet <- mixed.cor(x)
+	    typ = "poly"} else {tet <- mixedCor(x)
 	    typ="mixed" }	    
 	  } 
    
@@ -34,6 +37,7 @@ if(length(pvars)==ncol(x)) {tet <- polychoric(x)
          } 
   #now, if there are keys, find the correlations of the scales       
    if(!is.null(keys)) {bad <- FALSE
+   if(!is.matrix(keys)) keys <- make.keys(x,keys)  #handles the new normal way of just passing a keys list
          if(any(is.na(Rho))) {warning(sum(is.na(Rho)), " of the item correlations are NA and thus finding scales that include those items will not work.\n We will try to do it for those  scales which do not include those items.
          \n Proceed with caution. ") 
          bad <- TRUE
@@ -64,15 +68,17 @@ if(length(pvars)==ncol(x)) {tet <- polychoric(x)
   rho <- cov2cor(rho)     #scale covariances to correlations  
   nvar <- dim(rho)[2]
  
+  
  if(n.iter > 1) {
  	replicates <- list()
  	rep.rots <- list()
  	##now replicate it to get confidence intervals
-
+   #replicates <- lapply(1:n.iter,function(XX) {
+   
  		replicates <- mclapply(1:n.iter,function(XX) {
 		 xs <- x[sample(n.obs,n.obs,replace=TRUE),]
  		{if(poly) {
- 		 if(typ!= "tet") {tets <- mixed.cor(xs)} else {tets <- tetrachoric(xs)}
+ 		 if(typ!= "tet") {tets <- mixedCor(xs)} else {tets <- tetrachoric(xs)}
 
   	R <- tets$rho} else {R <- cor(xs,use="pairwise",method=method)}  #R is the big correlation matrix
  
@@ -107,7 +113,7 @@ if(length(pvars)==ncol(x)) {tet <- polychoric(x)
      means.rot <- colMeans(z.rot,na.rm=TRUE)
       sds.rot <- apply(z.rot,2,sd, na.rm=TRUE)
       sds.rot <- fisherz2r(sds.rot)
-      ci.rot.lower <- means.rot + qnorm(p/2) * sds.rot
+      ci.rot.lower <- means.rot + qnorm(p/2) * sds.rot  #This is the normal value of the observed distribution
       ci.rot.upper <- means.rot + qnorm(1-p/2) * sds.rot
       means.rot <- fisherz2r(means.rot)
       ci.rot.lower <- fisherz2r(ci.rot.lower)
@@ -115,8 +121,8 @@ if(length(pvars)==ncol(x)) {tet <- polychoric(x)
       low.e <- apply(replicates,2,quantile, p/2,na.rm=TRUE)
       up.e  <- apply(replicates, 2, quantile, 1-p/2,na.rm=TRUE)
       tci <- abs(means.rot)/sds.rot
-      ptci <- pnorm(tci)
-      ci.rot <- data.frame(lower=ci.rot.lower,low.e=low.e,upper=ci.rot.upper,up.e=up.e,p =2*(1-ptci))
+      ptci <- 1- pnorm(tci)    #subtract from 1 (added 11/14/20)
+      ci.rot <- data.frame(lower=ci.rot.lower,low.e=low.e,upper=ci.rot.upper,up.e=up.e,p =2*(ptci))   #dropped the 1-ptci 11/14/20
       cnR <- abbreviate(colnames(rho),minlength=minlength) 
       k <- 1
      for(i in 1:(nvar-1)) {for (j in (i+1):nvar) {
@@ -131,7 +137,15 @@ results <- list(rho=rho, means=means.rot,sds=sds.rot,tci=tci,ptci=ptci,ci=ci.rot
 if(plot) {cor.plot(rho,numbers=TRUE,cuts=c(.001,.01,.05),pval =  2*(1-ptci),...) }
 class(results) <- c("psych","cor.ci")
     
+return(results)  } else {#we have been given correlations, just find the cis.
+if(is.null(n)) {warning("\nFinding confidence intervals from a correlation matrix, but  n is not specified, arbitrarily set to 1000")
+   n <- 1000}
+results <- cor.Ci(x,n=n, alpha=p, minlength=minlength)
+results$ci <- results$r.ci
+results$r <- x
+class(results) <- cs(psych, corCi)
 return(results)
+}
 
  }
  #written Sept 20, 2013 
