@@ -99,6 +99,8 @@ fit <- matrix(unlist(fit.list),nrow=ncases,byrow=TRUE)
 return(fits)
 }
 
+#revised 9/15/18 to handle radians correctly and to handle character names for variables
+
 "circadian.phase" <- 
 "cosinor" <- 
 function(angle,x=NULL,code=NULL,data = NULL, hours=TRUE,period=24,plot=FALSE,opti=FALSE,na.rm=TRUE) {
@@ -106,7 +108,9 @@ function(angle,x=NULL,code=NULL,data = NULL, hours=TRUE,period=24,plot=FALSE,opt
   if(!is.null(data)) {
       if(is.matrix(data)) data <- data.frame(data)
        if(is.character(angle)) angle <- which(colnames(data) == angle)
+       if(is.character(x)) x <- which(colnames(data) ==x)
      if(!is.null(code)) { if(is.character(code))  codeloc <- which(colnames(data) ==code)
+             
               x <- data[,c(angle,x,codeloc)] } else {x <- data[,c(angle,x)]}
                angle <- x[1]
                x <- x[-1]
@@ -120,8 +124,8 @@ function(angle,x=NULL,code=NULL,data = NULL, hours=TRUE,period=24,plot=FALSE,opt
                   x <- x[-1]
                  }               
      } 
-if(hours) { angle <- angle*2*pi/period 
-  x <- cbind(angle,x)}  #convert to radians
+if(hours) { angle <- angle*2*pi/period }   #convert to radians
+  x <- cbind(angle,x) 
 
 nvar <- dim(x)[2]
 if(is.null(code)) { fit <- cosinor1(angle,x[-1],period=period,opti=opti,na.rm=na.rm)  #if there is a code (i.e., subject id), then do the fits for each separate subject
