@@ -44,9 +44,28 @@ alpha = {
 	print(x$call)
 	cat("\n ")
 	print(x$total,digits=digits)
-	if(!is.null(x$total$ase)){ cat("\n lower alpha upper     95% confidence boundaries\n")
-	cat(round(c(x$total$raw_alpha - 1.96* x$total$ase, x$total$raw_alpha,x$total$raw_alpha +1.96* x$total$ase),digits=digits) ,"\n")}
-	if(!is.null(x$boot.ci)) {cat("\n lower median upper bootstrapped confidence intervals\n",round(x$boot.ci,digits=digits))}
+	
+	cat("\n    95% confidence boundaries \n")
+	temp.df <- data.frame(lower=x$feldt$lower.ci, alpha= x$feldt$alpha,upper.ci =x$feldt$upper.ci)
+	 colnames(temp.df ) <- c("lower","alpha","upper")
+	 rownames(temp.df) <- "Feldt"
+	if(!is.null(x$total$ase)){ 
+		temp.df[2,] <- c(x$total$raw_alpha - 1.96* x$total$ase, x$total$raw_alpha,x$total$raw_alpha +1.96* x$total$ase)
+	#cat(round(c(x$total$raw_alpha - 1.96* x$total$ase, x$total$raw_alpha,x$total$raw_alpha +1.96* x$total$ase),digits=digits) ,"\n")}
+	#if(!is.null(x$feldt)) {cat("\n 95% confidence boundaries   (Feldt) \n")
+	
+	#temp.df <- data.frame(lower=x$feldt$lower.ci, alpha= x$feldt$alpha,upper.ci =x$feldt$upper.ci)
+	
+		 rownames(temp.df)[2]<- "Duhachek"
+		}
+	
+	if(!is.null(x$boot.ci)) { #{cat("\n lower median upper bootstrapped confidence intervals\n",round(x$boot.ci,digits=digits))}
+	  temp.df[3,] <- x$boot.ci
+	  rownames(temp.df)[3] <- "bootstrapped"}
+	print(round(temp.df,digits))
+	
+	
+	
 	cat("\n Reliability if an item is dropped:\n")
     print(x$alpha.drop,digits=digits)
 	cat("\n Item statistics \n")
@@ -56,6 +75,13 @@ alpha = {
 	 print(round(x$response.freq,digits=digits))}
 },
 
+alpha.ci = { cat("\n   95% confidence boundaries (Feldt)\n")
+temp.df <- data.frame(lower=x$lower.ci, alpha= x$alpha,upper.ci =x$upper.ci)
+ colnames(temp.df ) <- c("lower","alpha","upper")
+ rownames(temp.df)<-""
+ print(round (temp.df,digits))
+},
+
 autoR = {cat("\nAutocorrelations \n")
       if(!is.null(x$Call)) {cat("Call: ")
            print(x$Call)}
@@ -228,6 +254,14 @@ cohen.d.by = {cat("Call: ")
              }
              cat("\nUse summary for more compact output")
             },
+            
+cohen.profile = {cat("Cohen Profile  coefficients \n")
+             print(round(unclass(x),digits=digits))},
+            
+congruence = {cat("Congruence coefficients \n")
+             print(round(unclass(x),digits=digits))},
+
+
 
 comorbid = {cat("Call: ")
             print(x$Call)
@@ -271,7 +305,7 @@ corr.test = {cat("Call:")
               cat("Sample Size \n")
               print(x$n)
               if(x$sym) {cat("Probability values (Entries above the diagonal are adjusted for multiple tests.) \n")} else {
-                 if (x$adjust != "none" )  {cat("Probability values  adjusted for multiple tests. \n")}}
+                 if (x$adjust != "none" )  {cat("These are the unadjusted probability values.\n  The probability values  adjusted for multiple tests are in the p.adj object. \n")}}
              print(round(x$p,digits))
             if(short)  cat("\n To see confidence intervals of the correlations, print with the short=FALSE option\n")
              if(!short) {cat("\n Confidence intervals based upon normal theory.  To get bootstrapped values, try cor.ci\n")
@@ -287,7 +321,7 @@ corr.p = {cat("Call:")
               cat("Sample Size \n")
               print(x$n)
               if(x$sym) {cat("Probability values (Entries above the diagonal are adjusted for multiple tests.) \n")} else {
-                 if (x$adjust != "none" )  {cat("Probability values  adjusted for multiple tests. \n")}}
+                 if (x$adjust != "none" )  {cat("These are the unadjusted probability values. \n To see the values  adjusted for multiple tests see the p.adj object. \n")}}
              print(round(x$p,digits))
              if(short) cat("\n To see confidence intervals of the correlations, print with the short=FALSE option\n")
               if(!short) {cat("\n Confidence intervals based upon normal theory.  To get bootstrapped values, try cor.ci\n")
@@ -308,7 +342,8 @@ cor.wt = {cat("Weighted Correlations \n")
             print(x$Call)
         lowerMat(x$r,digits=digits) },
 
-crossV = {cat("Cross Validation\n")
+crossV = {if(is.null(x$mean.fit)) {
+            cat("Cross Validation\n")
           cat("Call:")
             print(x$Call)
          cat("\nValidities from raw items and from the correlation matrix\n")
@@ -318,6 +353,13 @@ crossV = {cat("Cross Validation\n")
          lowerMat(x$item.R)
           cat("\nCorrelations based upon correlation matrix based regressions\n")
          lowerMat(x$mat.R)
+         } else {cat("Bootstrapped Cross Validation\n")
+          cat("Call:")
+            print(x$Call)
+            print(round(x$mean.fit,digits=digits))
+            cat("\n With average coefficents of \n")
+            print(round(x$mean.coeff,digits=digits))
+        }
           },
          
 
@@ -395,6 +437,14 @@ faCor = { cat("Call: ")
      cat("\n Factor congruence between the two solutions\n")     
        print(x$congruence,digits=digits)
 },
+fa.reg ={cat("Call: ")
+        print(x$Call)
+          if(!short) { cat("\n Factor analysis based regression \n")    
+        print (x$regression)} else { cat("\n Factor analysis based regression \n")
+        summary(x$regression)
+        cat("\n set short = FALSE to see the detailed statistics \n" )
+        }
+        },
     
 guttman =  {
   cat("Call: ")
@@ -412,7 +462,7 @@ guttman =  {
             cat("\nIntraclass correlation coefficients \n")
             print(x$results,digits=digits)
             cat("\n Number of subjects =", x$n.obs, "    Number of Judges = ",x$n.judge)
-
+            cat("\nSee the help file for a discussion of the other 4 McGraw and Wong estimates,")
    },
    
 iclust.sort = {
@@ -476,9 +526,9 @@ mardia =  {
      cat("\nMardia tests of multivariate skew and kurtosis\n")
      cat("Use describe(x) the to get univariate tests")
       cat("\nn.obs =",x$n.obs,"  num.vars = ",x$n.var,"\n")
-     cat("b1p = ",round(x$b1p,digits),"  skew = ",round(x$skew,digits ), " with probability = ", signif(x$p.skew,digits)) 
-     cat("\n small sample skew = ",round(x$small.skew,digits ), " with probability = ", signif(x$p.small,digits)) 
-     cat("\nb2p = ", round(x$b2p,digits),"  kurtosis = ",round(x$kurtosis,digits)," with probability = ",signif(x$p.kurt,digits ))
+     cat("b1p = ",round(x$b1p,digits),"  skew = ",round(x$skew,digits ), " with probability  <= ", signif(x$p.skew,digits)) 
+     cat("\n small sample skew = ",round(x$small.skew,digits ), " with probability <= ", signif(x$p.small,digits)) 
+     cat("\nb2p = ", round(x$b2p,digits),"  kurtosis = ",round(x$kurtosis,digits)," with probability <= ",signif(x$p.kurt,digits ))
   },
 
   
@@ -501,7 +551,7 @@ mixed= { cat("Call: ")
     if(is.null(x$rho)) {if(lower) {lowerMat(x,digits=digits)} else {print(x,digits)} } else {
     if(lower) {if(length(x$rho)>1) { lowerMat (x$rho,digits=digits)} else {print(x$rho,digits)}}
    }},
-   
+
    
 omegaDirect ={ cat("Call: ")
         print(x$Call)
@@ -675,6 +725,13 @@ polydi= {cat("Call: ")
     }
     },
 
+validity = { cat("Call: ")
+    print(x$Call)
+	cat("\nPredicted Asymptotic Scale Validity:\n")
+	  print(x$asymptotic,digits) 
+	 cat("\n For predicted scale validities, average item validities, or scale reliabilities, print the separate objects")
+     }, 
+
 overlap =  {
     cat("Call: ")
     print(x$Call)
@@ -690,9 +747,18 @@ overlap =  {
 	print(x$size)
 	cat("\nSignal to Noise ratio based upon average r and n \n")
 	print(x$sn,digits=digits)
+
 	
 	 cat("\nScale intercorrelations corrected for item overlap and attenuation \n adjusted for overlap correlations below the diagonal, alpha on the diagonal \n corrected correlations above the diagonal:\n")
 	 print(x$corrected,digits) 
+	 
+	 if(!is.null(x$quality) ) {cat("\n Percentage of keyed items with highest absolute correlation with scale  (scale quality)\n")
+	     print(x$quality,digits=2) }
+	 if(!is.null(x$MIMS) ) {cat("\n Average adjusted correlations within and between scales (MIMS)\n")
+	   lowerMat(x$MIMS) }
+	   
+	if(!is.null(x$MIMT) ) {cat("\n Average adjusted item x scale correlations within and between scales (MIMT)\n")
+	   lowerMat(x$MIMT) }
 	
 	 if(short) {cat("\n In order to see the item by scale loadings and frequency counts of the data\n print with the short option = FALSE") } else {
 	  if(!is.null(x$item.cor) ) {
@@ -712,7 +778,14 @@ r.test =  {cat("Correlation tests \n")
               if(!is.null(x$t)) {cat(" t value" ,round(x$t,digits),"   with probability <", signif(x$p,digits) )}
               if(!is.null(x$z)) {cat(" z value" ,round(x$z,digits),"   with probability ",  round(x$p,digits) )}               
               if(!is.null(x$ci)) {cat("\n and confidence interval ",round(x$ci,digits) ) }
-         },   
+         }, 
+        
+reliability ={cat("Measures of reliability \n")
+            if(is.list(x)) {
+            print(x$Call)
+            x <- x$result.df}
+            print(round(unclass(x),digits))
+            },  
          
 residuals = { if(NCOL(x) == NROW(x)) {
    if (lower) {lowerMat (x,digits=digits)}} else {print(round(unclass(x),digits))}  #tweaked 1/30/18
@@ -753,6 +826,12 @@ scores =  {
 	 	if(!is.null(x$alpha.ob)) {cat("\nNote that these are the correlations of the complete scales based on the correlation matrix,\n not the observed scales based on the raw items.\n")}
 	 	
 	 print(x$corrected,digits) 
+	 
+	 if(!is.null(x$MIMS) ) {cat("\n Average adjusted correlations within and between scales (MIMS)\n")
+	   lowerMat(x$MIMS) }
+	   
+	if(!is.null(x$MIMT) ) {cat("\n Average adjusted item x scale correlations within and between scales (MIMT)\n")
+	   lowerMat(x$MIMT) }
 	 if(short) {cat("\n In order to see the item by scale loadings and frequency counts of the data\n print with the short option = FALSE") } else {
 	  if(!is.null(x$item.cor) ) {
 	   cat("\nItem by scale correlations:\n corrected for item overlap and scale reliability\n" )
@@ -765,6 +844,20 @@ scores =  {
 	
   },
   
+scoreBy = { cat("Call: ")
+    print(x$Call)
+    ngroup <- length(x$cor)
+    for(i in 1:ngroup) {
+   # cat("\n group = ",names(x$cor[i]),"\n")
+   if(!is.na(x$cor[[i]])) {
+   cat("\n Correlations for group",names(x$cor[i]),"\n")
+   lowerMat(x$cor[[i]]$cor)
+   cat("\n alpha \n")
+   print(round(x$alpha[[i]]$alpha,digits))
+   }}
+   cat("\n To see the correlations as a matrix, examine the cor.mat object ")
+    },
+
 setCor= { cat("Call: ")
                           print(x$Call)
             if(x$raw) {cat("\nMultiple Regression from raw data \n")} else {
@@ -773,8 +866,8 @@ setCor= { cat("Call: ")
             ny <- NCOL(x$coefficients)
           for(i in 1:ny) {cat("\n DV = ",colnames(x$coefficients)[i], "\n")
        #   if(!is.na(x$intercept[i])) {cat(' intercept = ',round(x$intercept[i],digits=digits),"\n")}
-          if(!is.null(x$se)) {result.df <- data.frame( round(x$coefficients[,i],digits),round(x$se[,i],digits),round(x$t[,i],digits),signif(x$Probability[,i],digits),round(x$ci[,i],digits), round(x$ci[,(i +ny)],digits),round(x$VIF,digits))
-              colnames(result.df) <- c("slope","se", "t", "p","lower.ci","upper.ci",  "VIF")        
+          if(!is.null(x$se)) {result.df <- data.frame( round(x$coefficients[,i],digits),round(x$se[,i],digits),round(x$t[,i],digits),signif(x$Probability[,i],digits),round(x$ci[,i],digits), round(x$ci[,(i +ny)],digits),round(x$VIF,digits),round(x$Vaxy[,i],digits))
+              colnames(result.df) <- c("slope","se", "t", "p","lower.ci","upper.ci",  "VIF","Vy.x")        
               print(result.df) 
                cat("\nResidual Standard Error = ",round(x$SE.resid[i],digits), " with ",x$df[2], " degrees of freedom\n")     
               result.df <- data.frame(R = round(x$R[i],digits), R2 = round(x$R2[i],digits), Ruw = round(x$ruw[i],digits),R2uw =  round( x$ruw[i]^2,digits), round(x$shrunkenR2[i],digits),round(x$seR2[i],digits), round(x$F[i],digits),x$df[1],x$df[2], signif(x$probF[i],digits+1))
@@ -782,8 +875,8 @@ setCor= { cat("Call: ")
               cat("\n Multiple Regression\n")
              print(result.df)
               } else {
-              result.df <- data.frame( round(x$coefficients[,i],digits),round(x$VIF,digits))
-              colnames(result.df) <- c("slope", "VIF")        
+              result.df <- data.frame( round(x$coefficients[,i],digits),round(x$VIF,digits),round(x$Vaxy[,i],digits))
+              colnames(result.df) <- c("slope", "VIF","Vy.x")        
               print(result.df)      
               result.df <- data.frame(R = round(x$R[i],digits), R2 = round(x$R2[i],digits), Ruw = round(x$ruw[i],digits),R2uw =  round( x$ruw[i]^2,digits))
               colnames(result.df) <- c("R","R2", "Ruw", "R2uw")
