@@ -19,10 +19,10 @@ function(fx=NULL,Phi=NULL,fy=NULL,labels=NULL,cut=.3,errors=FALSE,simple=TRUE,re
   e.size <- e.size*8/(NROW(fx))
  #check if input is from a factor analysis or omega analysis
  if(!is.null(class(xmodel)) && (length(class(xmodel))>1)) {
-   if(class(xmodel)[1] =="psych" && class(xmodel)[2] =="omega") {
+   if((inherits(xmodel,"psych") && inherits(xmodel, "omega"))) {
     Phi <- xmodel$schmid$phi
     xmodel <- xmodel$schmid$oblique} else {
-   if(class(xmodel)[1] =="psych" && ((class(xmodel)[2] =="fa") | (class(xmodel)[2] =="principal"))) { if(!is.null(xmodel$Phi)) Phi <- xmodel$Phi
+   if((inherits(xmodel,"psych") && ((inherits(xmodel,"fa") | (inherits(xmodel,"principal")))))) { if(!is.null(xmodel$Phi)) Phi <- xmodel$Phi
         xmodel <- as.matrix(xmodel$loadings)} 
          }} else {
  if(!is.matrix(xmodel) & !is.data.frame(xmodel) &!is.vector(xmodel))  {
@@ -115,7 +115,7 @@ length.labels <-  0    # a filler for now
 #strwd <- try(strwidth(xvars),silent=TRUE)
 strwd <- try(length.labels <- max(strwidth(xvars),strwidth("abc"))/1.8,silent=TRUE)  #although this throws an error if the window is not already open, we don't show it
 #if (class(strwd) == "try-error" ) {plot.new() } 
-if (class(strwd) == "try-error" ) {length.labels = max(nchar(xvars),3)/1.8 } 
+if (inherits(strwd, "try-error" )) {length.labels = max(nchar(xvars),3)/1.8 } 
 #length.labels <- max(strwidth(xvars),strwidth("abc"))/1.8
 
 if(lr) {limx <- c(-(length.labels + x.curves+ errors/4),max(num.xvar,num.yvar)+2 + y.curves) 
